# frozen_string_literal: true

require_relative '../../response/contributors_response'
require_relative '../../response/investors_response'
require_relative '../../request/contributors_request_handler'
require_relative '../../request/investors_request_handler'

module ONEAccess
  module API
    module V3_0
      class References < Base
        api_path '/references'

        class << self
          def contributors(contributor_names: nil, limit: 20, offset: 0)
            params = {
              contributor_names: contributor_names,
              limit:             limit,
              offset:            offset,
            }.reject { |_, v| v.nil? }

            resp = send_get('contributors', params)

            Response::ContributorsResponse.from_json(resp.body)
          end

          def contributors_list
            Request::ContributorsRequestHandler.new(url: api_url('contributors'))
          end

          def investors(investor_names: nil, limit: 20, offset: 0)
            params = {
              investor_names: investor_names,
              limit:          limit,
              offset:         offset,
            }.reject { |_, v| v.nil? }

            resp = send_get('investors', params)

            Response::InvestorsResponse.from_json(resp.body)
          end

          def investors_list
            Request::InvestorsRequestHandler.new(url: api_url('investors'))
          end
        end
      end
    end
  end
end
