# frozen_string_literal: true

require 'logger'

module ONEAccess
  class Configuration
    DEFAULT_BASE_URL = 'http://ws.oneaccess.io'
    DEFAULT_BASE_V1_1_PATH = '/v1.1'
    DEFAULT_BASE_V3_0_PATH = '/v3.0'

    class << self
      attr_accessor :base_url
      attr_accessor :api_key
      attr_accessor :master_api_key
      attr_writer :logger
      attr_accessor :log_requests

      def base_v1_1_url
        "#{base_url}#{DEFAULT_BASE_V1_1_PATH}"
      end

      def base_v3_0_url
        "#{base_url}#{DEFAULT_BASE_V3_0_PATH}"
      end

      def reset!
        self.base_url = DEFAULT_BASE_URL
        self.api_key = nil
        self.master_api_key = nil
      end

      def logger
        @logger ||= Logger.new(STDOUT)
      end
    end

    reset!
  end
end
